Coverage for airflow.migrations.versions.338e90f54d61_more_logging_into_task_isntance: 69%

# Coverage for airflow.migrations.versions.338e90f54d61_more_logging_into_task_isntance : 69%

## 13 statements 9 run 4 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 | """More logging into task_isntance Revision ID: 338e90f54d61 Revises: 13eb55f81627 Create Date: 2015-08-25 06:09:20.460147 """ # revision identifiers, used by Alembic. revision = '338e90f54d61' down_revision = '13eb55f81627' branch_labels = None depends_on = None from alembic import op import sqlalchemy as sa from sqlalchemy.dialects import mysql def upgrade(): ### commands auto generated by Alembic - please adjust! ### op.add_column('task_instance', sa.Column('operator', sa.String(length=1000), nullable=True)) op.add_column('task_instance', sa.Column('queued_dttm', sa.DateTime(), nullable=True)) def downgrade(): ### commands auto generated by Alembic - please adjust! ### op.drop_column('task_instance', 'queued_dttm') op.drop_column('task_instance', 'operator') ### end Alembic commands ###